from omni.pro.cloudmap import CloudMap
from omni.pro.database import RedisManager
from omni.pro.config import Config


def get_redis_manager() -> RedisManager:
    if Config.DEBUG:
        return RedisManager(host=Config.REDIS_HOST, port=Config.REDIS_PORT, db=Config.REDIS_DB)
    # logger.info(f"Cloud Map: {cm_params}")
    cloud_map = CloudMap()

    redis_params = cloud_map.get_redis_config()
    # logger.info(f"Redis params: {redis_params}")

    redis_manager = RedisManager(**redis_params)
    return redis_manager



import importlib
import inspect
import pathlib

import networkx as nx
import peewee
from mongoengine.document import Document
from omni.pro.logger import configure_logger
from omni.pro.models.base import BaseDocument, BaseModel
from peewee import ForeignKeyField

logger = configure_logger(__name__)


class Topology(object):
    def __init__(self, path_models):
        self.path_models = path_models

    def sort_models_topologically(self, models: list) -> list:
        graph = nx.DiGraph()

        # Agrega todos los modelos como nodos en el gráfico.
        for model in models:
            graph.add_node(model)

        # Agrega aristas para todas las relaciones de clave foránea.
        for model in models:
            for field in model._meta.sorted_fields:
                if isinstance(field, ForeignKeyField):
                    # Ignora las relaciones recursivas
                    if field.rel_model != model:
                        graph.add_edge(model, field.rel_model)

        # Intenta encontrar y eliminar ciclos
        while not nx.is_directed_acyclic_graph(graph):
            try:
                # Encuentra un ciclo
                cycle = nx.find_cycle(graph, orientation="original")

                # Imprime los nodos que forman un ciclo y sus dependencias
                logger.warning("# Found a cycle:")
                for edge in cycle:
                    logger.warning(f"# {edge[0]} -> {edge[1]}")

                # Elimina una arista del ciclo
                graph.remove_edge(cycle[0][0], cycle[0][1])
            except:
                break

        # Devuelve los modelos en un orden topológico.
        return list(nx.topological_sort(graph))

    def get_model_classes_from_module(self, module_name_list: list) -> list:
        model_classes = []
        for module_name in module_name_list:
            # Importa el módulo
            module = importlib.import_module(module_name)

            # Encuentra todas las clases de modelos en el módulo
            for name, obj in inspect.getmembers(module):
                if inspect.isclass(obj) and (
                    (issubclass(obj, BaseModel) and obj != BaseModel)
                    or (issubclass(obj, Document) and obj != BaseDocument)
                ):
                    model_classes.append(obj)

        return model_classes

    def get_model_libs(self: pathlib.Path) -> list[str]:
        return [
            f"models.{path.stem}" for path in pathlib.Path(self.path_models).glob("**/*.py") if path.stem != "__init__"
        ]

    def get_models_from_libs(self) -> list[str]:
        model_libs = self.get_model_libs()
        model_classes = self.get_model_classes_from_module(model_libs)
        return list(set(model_classes))

    def logger_to_imports(self):
        # Ejemplo de uso
        model_libs = self.get_model_libs()
        model_classes = self.get_model_classes_from_module(model_libs)

        # Esto imprimirá los nombres de todas las clases de modelos en el módulo
        # for model_class in model_classes:
        #     print(model_class.__name__)

        model_top = self.sort_models_topologically(model_classes)
        model_top.reverse()
        for x in model_top:
            logger.info(f"from {x.__module__} import {x.__name__}")

        for x in model_top:
            logger.info(f"migrator.create_model({x.__name__})")



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import delivery_locality_pb2 as v1_dot_rules_dot_delivery__locality__pb2


class DeliveryLocalityServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DeliveryLocalityCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_locality.DeliveryLocalityService/DeliveryLocalityCreate",
            request_serializer=v1_dot_rules_dot_delivery__locality__pb2.DeliveryLocalityCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__locality__pb2.DeliveryLocalityCreateResponse.FromString,
        )
        self.DeliveryLocalityRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_locality.DeliveryLocalityService/DeliveryLocalityRead",
            request_serializer=v1_dot_rules_dot_delivery__locality__pb2.DeliveryLocalityReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__locality__pb2.DeliveryLocalityReadResponse.FromString,
        )
        self.DeliveryLocalityUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_locality.DeliveryLocalityService/DeliveryLocalityUpdate",
            request_serializer=v1_dot_rules_dot_delivery__locality__pb2.DeliveryLocalityUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__locality__pb2.DeliveryLocalityUpdateResponse.FromString,
        )
        self.DeliveryLocalityDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_locality.DeliveryLocalityService/DeliveryLocalityDelete",
            request_serializer=v1_dot_rules_dot_delivery__locality__pb2.DeliveryLocalityDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__locality__pb2.DeliveryLocalityDeleteResponse.FromString,
        )
        self.AddTerritoryMatrixValue = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_locality.DeliveryLocalityService/AddTerritoryMatrixValue",
            request_serializer=v1_dot_rules_dot_delivery__locality__pb2.AddTerritoryMatrixValueRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__locality__pb2.AddTerritoryMatrixValueResponse.FromString,
        )
        self.RemoveTerritoryMatrixValue = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_locality.DeliveryLocalityService/RemoveTerritoryMatrixValue",
            request_serializer=v1_dot_rules_dot_delivery__locality__pb2.RemoveTerritoryMatrixValueRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__locality__pb2.RemoveTerritoryMatrixValueResponse.FromString,
        )


class DeliveryLocalityServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DeliveryLocalityCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryLocalityRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryLocalityUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryLocalityDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AddTerritoryMatrixValue(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RemoveTerritoryMatrixValue(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_DeliveryLocalityServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "DeliveryLocalityCreate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryLocalityCreate,
            request_deserializer=v1_dot_rules_dot_delivery__locality__pb2.DeliveryLocalityCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__locality__pb2.DeliveryLocalityCreateResponse.SerializeToString,
        ),
        "DeliveryLocalityRead": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryLocalityRead,
            request_deserializer=v1_dot_rules_dot_delivery__locality__pb2.DeliveryLocalityReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__locality__pb2.DeliveryLocalityReadResponse.SerializeToString,
        ),
        "DeliveryLocalityUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryLocalityUpdate,
            request_deserializer=v1_dot_rules_dot_delivery__locality__pb2.DeliveryLocalityUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__locality__pb2.DeliveryLocalityUpdateResponse.SerializeToString,
        ),
        "DeliveryLocalityDelete": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryLocalityDelete,
            request_deserializer=v1_dot_rules_dot_delivery__locality__pb2.DeliveryLocalityDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__locality__pb2.DeliveryLocalityDeleteResponse.SerializeToString,
        ),
        "AddTerritoryMatrixValue": grpc.unary_unary_rpc_method_handler(
            servicer.AddTerritoryMatrixValue,
            request_deserializer=v1_dot_rules_dot_delivery__locality__pb2.AddTerritoryMatrixValueRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__locality__pb2.AddTerritoryMatrixValueResponse.SerializeToString,
        ),
        "RemoveTerritoryMatrixValue": grpc.unary_unary_rpc_method_handler(
            servicer.RemoveTerritoryMatrixValue,
            request_deserializer=v1_dot_rules_dot_delivery__locality__pb2.RemoveTerritoryMatrixValueRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__locality__pb2.RemoveTerritoryMatrixValueResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.delivery_locality.DeliveryLocalityService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class DeliveryLocalityService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DeliveryLocalityCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_locality.DeliveryLocalityService/DeliveryLocalityCreate",
            v1_dot_rules_dot_delivery__locality__pb2.DeliveryLocalityCreateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__locality__pb2.DeliveryLocalityCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryLocalityRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_locality.DeliveryLocalityService/DeliveryLocalityRead",
            v1_dot_rules_dot_delivery__locality__pb2.DeliveryLocalityReadRequest.SerializeToString,
            v1_dot_rules_dot_delivery__locality__pb2.DeliveryLocalityReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryLocalityUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_locality.DeliveryLocalityService/DeliveryLocalityUpdate",
            v1_dot_rules_dot_delivery__locality__pb2.DeliveryLocalityUpdateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__locality__pb2.DeliveryLocalityUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryLocalityDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_locality.DeliveryLocalityService/DeliveryLocalityDelete",
            v1_dot_rules_dot_delivery__locality__pb2.DeliveryLocalityDeleteRequest.SerializeToString,
            v1_dot_rules_dot_delivery__locality__pb2.DeliveryLocalityDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AddTerritoryMatrixValue(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_locality.DeliveryLocalityService/AddTerritoryMatrixValue",
            v1_dot_rules_dot_delivery__locality__pb2.AddTerritoryMatrixValueRequest.SerializeToString,
            v1_dot_rules_dot_delivery__locality__pb2.AddTerritoryMatrixValueResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def RemoveTerritoryMatrixValue(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_locality.DeliveryLocalityService/RemoveTerritoryMatrixValue",
            v1_dot_rules_dot_delivery__locality__pb2.RemoveTerritoryMatrixValueRequest.SerializeToString,
            v1_dot_rules_dot_delivery__locality__pb2.RemoveTerritoryMatrixValueResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.utilities import territory_matrix_pb2 as v1_dot_utilities_dot_territory__matrix__pb2


class TerritoryMatrixServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.TerritoryMatrixAdd = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.territory_matrix.TerritoryMatrixService/TerritoryMatrixAdd",
            request_serializer=v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixAddRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixAddResponse.FromString,
        )
        self.TerritoryMatrixRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.territory_matrix.TerritoryMatrixService/TerritoryMatrixRead",
            request_serializer=v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixReadRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixReadResponse.FromString,
        )
        self.TerritoryMatrixUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.territory_matrix.TerritoryMatrixService/TerritoryMatrixUpdate",
            request_serializer=v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixUpdateResponse.FromString,
        )
        self.TerritoryMatrixDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.territory_matrix.TerritoryMatrixService/TerritoryMatrixDelete",
            request_serializer=v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixDeleteResponse.FromString,
        )
        self.TerritoryMatrixLoad = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.territory_matrix.TerritoryMatrixService/TerritoryMatrixLoad",
            request_serializer=v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixLoadRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixLoadResponse.FromString,
        )
        self.TerritoryMatrixStructure = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.territory_matrix.TerritoryMatrixService/TerritoryMatrixStructure",
            request_serializer=v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixStructureRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixStructureResponse.FromString,
        )


class TerritoryMatrixServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def TerritoryMatrixAdd(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def TerritoryMatrixRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def TerritoryMatrixUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def TerritoryMatrixDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def TerritoryMatrixLoad(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def TerritoryMatrixStructure(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_TerritoryMatrixServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "TerritoryMatrixAdd": grpc.unary_unary_rpc_method_handler(
            servicer.TerritoryMatrixAdd,
            request_deserializer=v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixAddRequest.FromString,
            response_serializer=v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixAddResponse.SerializeToString,
        ),
        "TerritoryMatrixRead": grpc.unary_unary_rpc_method_handler(
            servicer.TerritoryMatrixRead,
            request_deserializer=v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixReadRequest.FromString,
            response_serializer=v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixReadResponse.SerializeToString,
        ),
        "TerritoryMatrixUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.TerritoryMatrixUpdate,
            request_deserializer=v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixUpdateRequest.FromString,
            response_serializer=v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixUpdateResponse.SerializeToString,
        ),
        "TerritoryMatrixDelete": grpc.unary_unary_rpc_method_handler(
            servicer.TerritoryMatrixDelete,
            request_deserializer=v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixDeleteRequest.FromString,
            response_serializer=v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixDeleteResponse.SerializeToString,
        ),
        "TerritoryMatrixLoad": grpc.unary_unary_rpc_method_handler(
            servicer.TerritoryMatrixLoad,
            request_deserializer=v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixLoadRequest.FromString,
            response_serializer=v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixLoadResponse.SerializeToString,
        ),
        "TerritoryMatrixStructure": grpc.unary_unary_rpc_method_handler(
            servicer.TerritoryMatrixStructure,
            request_deserializer=v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixStructureRequest.FromString,
            response_serializer=v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixStructureResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.utilities.territory_matrix.TerritoryMatrixService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class TerritoryMatrixService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def TerritoryMatrixAdd(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.territory_matrix.TerritoryMatrixService/TerritoryMatrixAdd",
            v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixAddRequest.SerializeToString,
            v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixAddResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def TerritoryMatrixRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.territory_matrix.TerritoryMatrixService/TerritoryMatrixRead",
            v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixReadRequest.SerializeToString,
            v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def TerritoryMatrixUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.territory_matrix.TerritoryMatrixService/TerritoryMatrixUpdate",
            v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixUpdateRequest.SerializeToString,
            v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def TerritoryMatrixDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.territory_matrix.TerritoryMatrixService/TerritoryMatrixDelete",
            v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixDeleteRequest.SerializeToString,
            v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def TerritoryMatrixLoad(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.territory_matrix.TerritoryMatrixService/TerritoryMatrixLoad",
            v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixLoadRequest.SerializeToString,
            v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixLoadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def TerritoryMatrixStructure(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.territory_matrix.TerritoryMatrixService/TerritoryMatrixStructure",
            v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixStructureRequest.SerializeToString,
            v1_dot_utilities_dot_territory__matrix__pb2.TerritoryMatrixStructureResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import delivery_schedule_pb2 as v1_dot_rules_dot_delivery__schedule__pb2


class DeliveryScheduleServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DeliveryScheduleCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_schedule.DeliveryScheduleService/DeliveryScheduleCreate",
            request_serializer=v1_dot_rules_dot_delivery__schedule__pb2.DeliveryScheduleCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__schedule__pb2.DeliveryScheduleCreateResponse.FromString,
        )
        self.DeliveryScheduleRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_schedule.DeliveryScheduleService/DeliveryScheduleRead",
            request_serializer=v1_dot_rules_dot_delivery__schedule__pb2.DeliveryScheduleReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__schedule__pb2.DeliveryScheduleReadResponse.FromString,
        )
        self.DeliveryScheduleUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_schedule.DeliveryScheduleService/DeliveryScheduleUpdate",
            request_serializer=v1_dot_rules_dot_delivery__schedule__pb2.DeliveryScheduleUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__schedule__pb2.DeliveryScheduleUpdateResponse.FromString,
        )
        self.DeliveryScheduleDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_schedule.DeliveryScheduleService/DeliveryScheduleDelete",
            request_serializer=v1_dot_rules_dot_delivery__schedule__pb2.DeliveryScheduleDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__schedule__pb2.DeliveryScheduleDeleteResponse.FromString,
        )


class DeliveryScheduleServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DeliveryScheduleCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryScheduleRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryScheduleUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryScheduleDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_DeliveryScheduleServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "DeliveryScheduleCreate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryScheduleCreate,
            request_deserializer=v1_dot_rules_dot_delivery__schedule__pb2.DeliveryScheduleCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__schedule__pb2.DeliveryScheduleCreateResponse.SerializeToString,
        ),
        "DeliveryScheduleRead": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryScheduleRead,
            request_deserializer=v1_dot_rules_dot_delivery__schedule__pb2.DeliveryScheduleReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__schedule__pb2.DeliveryScheduleReadResponse.SerializeToString,
        ),
        "DeliveryScheduleUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryScheduleUpdate,
            request_deserializer=v1_dot_rules_dot_delivery__schedule__pb2.DeliveryScheduleUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__schedule__pb2.DeliveryScheduleUpdateResponse.SerializeToString,
        ),
        "DeliveryScheduleDelete": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryScheduleDelete,
            request_deserializer=v1_dot_rules_dot_delivery__schedule__pb2.DeliveryScheduleDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__schedule__pb2.DeliveryScheduleDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.delivery_schedule.DeliveryScheduleService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class DeliveryScheduleService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DeliveryScheduleCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_schedule.DeliveryScheduleService/DeliveryScheduleCreate",
            v1_dot_rules_dot_delivery__schedule__pb2.DeliveryScheduleCreateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__schedule__pb2.DeliveryScheduleCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryScheduleRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_schedule.DeliveryScheduleService/DeliveryScheduleRead",
            v1_dot_rules_dot_delivery__schedule__pb2.DeliveryScheduleReadRequest.SerializeToString,
            v1_dot_rules_dot_delivery__schedule__pb2.DeliveryScheduleReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryScheduleUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_schedule.DeliveryScheduleService/DeliveryScheduleUpdate",
            v1_dot_rules_dot_delivery__schedule__pb2.DeliveryScheduleUpdateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__schedule__pb2.DeliveryScheduleUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryScheduleDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_schedule.DeliveryScheduleService/DeliveryScheduleDelete",
            v1_dot_rules_dot_delivery__schedule__pb2.DeliveryScheduleDeleteRequest.SerializeToString,
            v1_dot_rules_dot_delivery__schedule__pb2.DeliveryScheduleDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/delviery_shipper_warehouse.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n)v1/rules/delviery_shipper_warehouse.proto\x12\x34pro.omni.oms.api.v1.rules.delivery_shipper_warehouse\x1a\x11\x63ommon/base.proto"\xaa\x01\n\x18\x44\x65liveryShipperWarehouse\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x1b\n\x13\x64\x65livery_shipper_id\x18\x02 \x01(\x05\x12\x14\n\x0cwarehouse_id\x18\x03 \x01(\x05\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x12?\n\x0cobject_audit\x18\x05 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x92\x01\n%DeliveryShipperWarehouseCreateRequest\x12\x1b\n\x13\x64\x65livery_shipper_id\x18\x01 \x01(\x05\x12\x14\n\x0cwarehouse_id\x18\x02 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe7\x01\n&DeliveryShipperWarehouseCreateResponse\x12r\n\x1a\x64\x65livery_shipper_warehouse\x18\x01 \x01(\x0b\x32N.pro.omni.oms.api.v1.rules.delivery_shipper_warehouse.DeliveryShipperWarehouse\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x81\x03\n#DeliveryShipperWarehouseReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa0\x02\n$DeliveryShipperWarehouseReadResponse\x12r\n\x1a\x64\x65livery_shipper_warehouse\x18\x01 \x03(\x0b\x32N.pro.omni.oms.api.v1.rules.delivery_shipper_warehouse.DeliveryShipperWarehouse\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xd3\x01\n%DeliveryShipperWarehouseUpdateRequest\x12r\n\x1a\x64\x65livery_shipper_warehouse\x18\x01 \x01(\x0b\x32N.pro.omni.oms.api.v1.rules.delivery_shipper_warehouse.DeliveryShipperWarehouse\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe7\x01\n&DeliveryShipperWarehouseUpdateResponse\x12r\n\x1a\x64\x65livery_shipper_warehouse\x18\x01 \x01(\x0b\x32N.pro.omni.oms.api.v1.rules.delivery_shipper_warehouse.DeliveryShipperWarehouse\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"k\n%DeliveryShipperWarehouseDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"s\n&DeliveryShipperWarehouseDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\x9b\x07\n\x1f\x44\x65liveryShipperWarehouseService\x12\xdd\x01\n\x1e\x44\x65liveryShipperWarehouseCreate\x12[.pro.omni.oms.api.v1.rules.delivery_shipper_warehouse.DeliveryShipperWarehouseCreateRequest\x1a\\.pro.omni.oms.api.v1.rules.delivery_shipper_warehouse.DeliveryShipperWarehouseCreateResponse"\x00\x12\xd7\x01\n\x1c\x44\x65liveryShipperWarehouseRead\x12Y.pro.omni.oms.api.v1.rules.delivery_shipper_warehouse.DeliveryShipperWarehouseReadRequest\x1aZ.pro.omni.oms.api.v1.rules.delivery_shipper_warehouse.DeliveryShipperWarehouseReadResponse"\x00\x12\xdd\x01\n\x1e\x44\x65liveryShipperWarehouseUpdate\x12[.pro.omni.oms.api.v1.rules.delivery_shipper_warehouse.DeliveryShipperWarehouseUpdateRequest\x1a\\.pro.omni.oms.api.v1.rules.delivery_shipper_warehouse.DeliveryShipperWarehouseUpdateResponse"\x00\x12\xdd\x01\n\x1e\x44\x65liveryShipperWarehouseDelete\x12[.pro.omni.oms.api.v1.rules.delivery_shipper_warehouse.DeliveryShipperWarehouseDeleteRequest\x1a\\.pro.omni.oms.api.v1.rules.delivery_shipper_warehouse.DeliveryShipperWarehouseDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.delviery_shipper_warehouse_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_DELIVERYSHIPPERWAREHOUSE"]._serialized_start = 119
    _globals["_DELIVERYSHIPPERWAREHOUSE"]._serialized_end = 289
    _globals["_DELIVERYSHIPPERWAREHOUSECREATEREQUEST"]._serialized_start = 292
    _globals["_DELIVERYSHIPPERWAREHOUSECREATEREQUEST"]._serialized_end = 438
    _globals["_DELIVERYSHIPPERWAREHOUSECREATERESPONSE"]._serialized_start = 441
    _globals["_DELIVERYSHIPPERWAREHOUSECREATERESPONSE"]._serialized_end = 672
    _globals["_DELIVERYSHIPPERWAREHOUSEREADREQUEST"]._serialized_start = 675
    _globals["_DELIVERYSHIPPERWAREHOUSEREADREQUEST"]._serialized_end = 1060
    _globals["_DELIVERYSHIPPERWAREHOUSEREADRESPONSE"]._serialized_start = 1063
    _globals["_DELIVERYSHIPPERWAREHOUSEREADRESPONSE"]._serialized_end = 1351
    _globals["_DELIVERYSHIPPERWAREHOUSEUPDATEREQUEST"]._serialized_start = 1354
    _globals["_DELIVERYSHIPPERWAREHOUSEUPDATEREQUEST"]._serialized_end = 1565
    _globals["_DELIVERYSHIPPERWAREHOUSEUPDATERESPONSE"]._serialized_start = 1568
    _globals["_DELIVERYSHIPPERWAREHOUSEUPDATERESPONSE"]._serialized_end = 1799
    _globals["_DELIVERYSHIPPERWAREHOUSEDELETEREQUEST"]._serialized_start = 1801
    _globals["_DELIVERYSHIPPERWAREHOUSEDELETEREQUEST"]._serialized_end = 1908
    _globals["_DELIVERYSHIPPERWAREHOUSEDELETERESPONSE"]._serialized_start = 1910
    _globals["_DELIVERYSHIPPERWAREHOUSEDELETERESPONSE"]._serialized_end = 2025
    _globals["_DELIVERYSHIPPERWAREHOUSESERVICE"]._serialized_start = 2028
    _globals["_DELIVERYSHIPPERWAREHOUSESERVICE"]._serialized_end = 2951
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/utilities/currency.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1bv1/utilities/currency.proto\x12&pro.omni.oms.api.v1.utilities.currency\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xb6\x02\n\x08\x43urrency\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x1b\n\x13\x63urrency_unit_label\x18\x04 \x01(\t\x12\x1e\n\x16\x63urrency_subunit_label\x18\x05 \x01(\t\x12\x0c\n\x04rate\x18\x06 \x01(\x05\x12\x10\n\x08rounding\x18\x07 \x01(\x01\x12\x16\n\x0e\x64\x65\x63imal_places\x18\x08 \x01(\x05\x12\x0e\n\x06symbol\x18\t \x01(\t\x12\x10\n\x08position\x18\n \x01(\t\x12*\n\x06\x61\x63tive\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x0c \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xab\x02\n\x12\x43urrencyAddRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x1b\n\x13\x63urrency_unit_label\x18\x03 \x01(\t\x12\x1e\n\x16\x63urrency_subunit_label\x18\x04 \x01(\t\x12\x0c\n\x04rate\x18\x05 \x01(\x05\x12\x10\n\x08rounding\x18\x06 \x01(\x01\x12\x16\n\x0e\x64\x65\x63imal_places\x18\x07 \x01(\x05\x12\x0e\n\x06symbol\x18\x08 \x01(\t\x12\x10\n\x08position\x18\t \x01(\t\x12*\n\x06\x61\x63tive\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x07\x63ontext\x18\x0b \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa4\x01\n\x13\x43urrencyAddResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x42\n\x08\x63urrency\x18\x02 \x01(\x0b\x32\x30.pro.omni.oms.api.v1.utilities.currency.Currency"\xf1\x02\n\x13\x43urrencyReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe2\x01\n\x14\x43urrencyReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x44\n\ncurrencies\x18\x03 \x03(\x0b\x32\x30.pro.omni.oms.api.v1.utilities.currency.Currency"\x93\x01\n\x15\x43urrencyUpdateRequest\x12\x42\n\x08\x63urrency\x18\x01 \x01(\x0b\x32\x30.pro.omni.oms.api.v1.utilities.currency.Currency\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa7\x01\n\x16\x43urrencyUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x42\n\x08\x63urrency\x18\x02 \x01(\x0b\x32\x30.pro.omni.oms.api.v1.utilities.currency.Currency"[\n\x15\x43urrencyDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"c\n\x16\x43urrencyDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xd2\x04\n\x0f\x43urrencyService\x12\x88\x01\n\x0b\x43urrencyAdd\x12:.pro.omni.oms.api.v1.utilities.currency.CurrencyAddRequest\x1a;.pro.omni.oms.api.v1.utilities.currency.CurrencyAddResponse"\x00\x12\x8b\x01\n\x0c\x43urrencyRead\x12;.pro.omni.oms.api.v1.utilities.currency.CurrencyReadRequest\x1a<.pro.omni.oms.api.v1.utilities.currency.CurrencyReadResponse"\x00\x12\x91\x01\n\x0e\x43urrencyUpdate\x12=.pro.omni.oms.api.v1.utilities.currency.CurrencyUpdateRequest\x1a>.pro.omni.oms.api.v1.utilities.currency.CurrencyUpdateResponse"\x00\x12\x91\x01\n\x0e\x43urrencyDelete\x12=.pro.omni.oms.api.v1.utilities.currency.CurrencyDeleteRequest\x1a>.pro.omni.oms.api.v1.utilities.currency.CurrencyDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.utilities.currency_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_CURRENCY"]._serialized_start = 123
    _globals["_CURRENCY"]._serialized_end = 433
    _globals["_CURRENCYADDREQUEST"]._serialized_start = 436
    _globals["_CURRENCYADDREQUEST"]._serialized_end = 735
    _globals["_CURRENCYADDRESPONSE"]._serialized_start = 738
    _globals["_CURRENCYADDRESPONSE"]._serialized_end = 902
    _globals["_CURRENCYREADREQUEST"]._serialized_start = 905
    _globals["_CURRENCYREADREQUEST"]._serialized_end = 1274
    _globals["_CURRENCYREADRESPONSE"]._serialized_start = 1277
    _globals["_CURRENCYREADRESPONSE"]._serialized_end = 1503
    _globals["_CURRENCYUPDATEREQUEST"]._serialized_start = 1506
    _globals["_CURRENCYUPDATEREQUEST"]._serialized_end = 1653
    _globals["_CURRENCYUPDATERESPONSE"]._serialized_start = 1656
    _globals["_CURRENCYUPDATERESPONSE"]._serialized_end = 1823
    _globals["_CURRENCYDELETEREQUEST"]._serialized_start = 1825
    _globals["_CURRENCYDELETEREQUEST"]._serialized_end = 1916
    _globals["_CURRENCYDELETERESPONSE"]._serialized_start = 1918
    _globals["_CURRENCYDELETERESPONSE"]._serialized_end = 2017
    _globals["_CURRENCYSERVICE"]._serialized_start = 2020
    _globals["_CURRENCYSERVICE"]._serialized_end = 2614
# @@protoc_insertion_point(module_scope)



from typing import ClassVar as _ClassVar
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import struct_pb2 as _struct_pb2
from omni.pro.protos.common import base_pb2 as _base_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class StockBatcherRequest(_message.Message):
    __slots__ = ["stock_entries", "batch", "type", "context"]
    STOCK_ENTRIES_FIELD_NUMBER: _ClassVar[int]
    BATCH_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    stock_entries: _struct_pb2.ListValue
    batch: _struct_pb2.Struct
    type: str
    context: _base_pb2.Context
    def __init__(
        self,
        stock_entries: _Optional[_Union[_struct_pb2.ListValue, _Mapping]] = ...,
        batch: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        type: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class StockBatcherResponse(_message.Message):
    __slots__ = ["record"]
    RECORD_FIELD_NUMBER: _ClassVar[int]
    record: str
    def __init__(self, record: _Optional[str] = ...) -> None: ...



from omni.pro.microservice import MicroService
from omni.pro.protos.grpc_connector import Event, GRPClient


class ModelRPCFucntion(object):
    def __init__(self, context: dict) -> None:
        """
        :param context: context with tenant and user\n
        Example:
        ```
        context = {"tenant": "tenant_code", "user": "user_name"}
        ```
        """
        self.context = context
        self.service_id = MicroService.SAAS_MS_UTILITIES.value
        self.module_grpc = "v1.utilities.model_pb2_grpc"
        self.stub_classname = "ModelsServiceStub"
        self.module_pb2 = "v1.utilities.model_pb2"

        self.event: Event = Event(
            module_grpc=self.module_grpc,
            stub_classname=self.stub_classname,
            module_pb2=self.module_pb2,
            rpc_method=None,
            request_class=None,
        )

        self.client: GRPClient = GRPClient(self.service_id)

    def register_model(self, params: dict):
        self.event.update(
            dict(
                rpc_method="ModelCreate",
                request_class="ModelCreateRequest",
                params={"context": self.context} | params,
            )
        )
        return self.client.call_rpc_fuction(self.event) + (self.event,)

    def updated_model(self, params: dict):
        self.event.update(
            dict(
                rpc_method="ModelUpdate",
                request_class="ModelUpdateRequest",
                params={"context": self.context} | params,
            )
        )
        return self.client.call_rpc_fuction(self.event) + (self.event,)

    def read_model(self, params: dict):
        self.event.update(
            dict(
                rpc_method="ModelRead",
                request_class="ModelReadRequest",
                params={"context": self.context} | params,
            )
        )
        return self.client.call_rpc_fuction(self.event) + (self.event,)
